==> haskell-gnutls-0.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnutls
version: 0.2
id: gnutls-0.2-1YbRgBrQgYyDnx7f55JGkD
key: gnutls-0.2-1YbRgBrQgYyDnx7f55JGkD
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnutls/
synopsis: Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.
    .
    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.
category: Network
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.TLS.GNU
hidden-modules: Network.Protocol.TLS.GNU.ErrorT
                Network.Protocol.TLS.GNU.Foreign
abi: 1c2b046b940fb899c2fd19fe333accc0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/gnutls-0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/gnutls-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/gnutls-0.2
hs-libraries: HSgnutls-0.2-1YbRgBrQgYyDnx7f55JGkD
extra-libraries:
    gnutls gnutls
include-dirs: /usr/include/p11-kit-1
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    monads-tf-0.1.0.3-LFzloq0E7zXDh1tEBRqziX transformers-0.5.2.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             monads-tf-0.1.0.3-LFzloq0E7zXDh1tEBRqziX=f6b37cbc5825d723bf21971ba6dcebac
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
haddock-interfaces: /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html: /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnutls-0.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnutls
version: 0.2
id: gnutls-0.2-JbgeHpxEtznGCBhXpkk85D
key: gnutls-0.2-JbgeHpxEtznGCBhXpkk85D
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnutls/
synopsis: Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.
    .
    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.
category: Network
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.TLS.GNU
hidden-modules: Network.Protocol.TLS.GNU.ErrorT
                Network.Protocol.TLS.GNU.Foreign
abi: 0fdbc789a157ce45bc1031a8873ed40b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gnutls-0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/gnutls-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/gnutls-0.2
hs-libraries: HSgnutls-0.2-JbgeHpxEtznGCBhXpkk85D
extra-libraries:
    gnutls gnutls
include-dirs: /usr/include/p11-kit-1
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz=0c9b66ce3d9f82342ac301838c6515b5
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html: /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
